@@ -1,4 +1,3 @@
-# -*- mode:python; coding:utf-8 -*-
 # Copyright (c) 2021 IBM Corp. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -15,4 +14,4 @@
 """Common Kubernetes constants."""
 
 # Default Kubernetes resource types
-RESOURCE_TYPES_DEFAULT = ['nodes', 'pods', 'configmaps']
+RESOURCE_TYPES_DEFAULT = ["nodes", "pods", "configmaps"]
